@@ -283,6 +283,7 @@ class Season(db.Model):
     season_year_start = db.Column(db.Integer, nullable=False)
     series_id = db.Column(db.Integer, db.ForeignKey("series.series_id"))
     timestamp_add_season = db.Column(db.String(10), nullable=False)
+    episodes = db.relationship("Episode", backref="Season", lazy="dynamic")
 
     __table_args__ = (
         db.UniqueConstraint("series_id", "season_number", name="series_season"),
@@ -559,7 +560,9 @@ class Facenet_Haar_Prediction(db.Model):
     character_id = db.Column(
         db.Integer, db.ForeignKey("characters.character_id"), nullable=False
     )
-    facenet_haar_model_name = db.Column(db.String(24), nullable=False)
+    facenet_haar_model_name = db.Column(
+        db.String(24), db.ForeignKey("facenet_haar_models.model_name"), nullable=False
+    )
     timestamp_added = db.Column(db.String(10), nullable=False)
 
     __table_args__ = (
